==> angular-barcode-febraban-0.0.4.tgz: package/README.md <==
# angular-barcode-febraban
Angular Directive to Render Interleaved 2 of 5 Barcode


[![npm version](https://badge.fury.io/js/angular-barcode-febraban.svg)](https://badge.fury.io/js/angular-barcode-febraban)
[![Build Status](https://travis-ci.org/allansli/angular-barcode-febraban.svg?branch=develop)](https://travis-ci.org/allansli/angular-barcode-febraban)
[![Coverage Status](https://coveralls.io/repos/github/allansli/angular-barcode-febraban/badge.svg?branch=master)](https://coveralls.io/github/allansli/angular-barcode-febraban?branch=master)
[![NPM Downloads](https://img.shields.io/npm/dt/angular-barcode-febraban.svg)](https://www.npmjs.com/package/angular-barcode-febraban)
[![dependencies](https://david-dm.org/allansli/angular-barcode-febraban/status.svg)](https://david-dm.org/allansli/angular-barcode-febraban)
[![devDependencies](https://david-dm.org/allansli/angular-barcode-febraban/dev-status.svg)](https://david-dm.org/allansli/angular-barcode-febraban)

## Usage
1. Install **angular-barcode-febraban** using **npm**.
 * `npm install angular-barcode-febraban --save`
2. Include module **angular-barcode-febraban** into your app.
 * `angular.module("my.app", ["angular-barcode-febraban"]);`
3. Add **script** and **css** references in html.
 * `<script src="../node_modules/angular-barcode-febraban/dist/angular-barcode-febraban.min.js"></script>`
 * `<link rel="stylesheet" href="../node_modules/angular-barcode-febraban/dist/css/barcode.css" />`
4. Use the directive as example below:
 * `<ng-barcode-febraban barcode-sequence="1234567890"></ng-barcode-febraban>`

==> angular-barcode-febraban-0.0.5.tgz: package/README.md <==
# angular-barcode-febraban
Angular Directive to Render Interleaved 2 of 5 Barcode


[![npm version](https://badge.fury.io/js/angular-barcode-febraban.svg)](https://badge.fury.io/js/angular-barcode-febraban)
[![Build Status](https://travis-ci.org/allansli/angular-barcode-febraban.svg?branch=develop)](https://travis-ci.org/allansli/angular-barcode-febraban)
[![Coverage Status](https://coveralls.io/repos/github/allansli/angular-barcode-febraban/badge.svg?branch=master)](https://coveralls.io/github/allansli/angular-barcode-febraban?branch=master)
[![NPM Downloads](https://img.shields.io/npm/dt/angular-barcode-febraban.svg)](https://www.npmjs.com/package/angular-barcode-febraban)
[![dependencies](https://david-dm.org/allansli/angular-barcode-febraban/status.svg)](https://david-dm.org/allansli/angular-barcode-febraban)
[![devDependencies](https://david-dm.org/allansli/angular-barcode-febraban/dev-status.svg)](https://david-dm.org/allansli/angular-barcode-febraban)

## Usage
- Install **angular-barcode-febraban** using **npm**.
 * `npm install angular-barcode-febraban --save`
- Include module **angular-barcode-febraban** into your app.
 * `angular.module("my.app", ["angular-barcode-febraban"]);`
- Add **script** and **css** references in html.
 * `<script src="../node_modules/angular-barcode-febraban/dist/angular-barcode-febraban.min.js"></script>`
 * `<link rel="stylesheet" href="../node_modules/angular-barcode-febraban/dist/css/barcode.css" />`
- Use the directive as example below:
 * `<ng-barcode-febraban barcode-sequence="1234567890"></ng-barcode-febraban>`

## Demo
Please, see the live demo [here](http://htmlpreview.github.io/?https://github.com/allansli/angular-barcode-febraban/blob/master/demo/index_git.html).
